@@ -1,6 +1,6 @@
 from aiohttp import web
 from secure_aiohttp.defaults import CSP_DEFAULT
-from secure_aiohttp.utils import csp_builder, validate_csrf
+from secure_aiohttp.utils import csp_builder
 from secure_aiohttp.exceptions import CSRFtokenError
 
 
